************************************************************************************************
* GENERATE AVERAGE d_nis WITH CHINA
************************************************************************************************

use dni828, clear
keep if ifscode1 == 924

collapse (mean) dni, by(ifscode2 dec)
rename ifscode2 ifscode
sort ifscode dec
save dni_temp, replace

use dni828, clear
keep if ifscode2 == 924

collapse (mean) dni, by(ifscode1 dec)
rename ifscode1 ifscode
sort ifscode dec

append using dni_temp

collapse (mean) dni, by(ifscode dec)

sort ifscode dec
save dni_withChina, replace
erase dni_temp.dta

************************************************************************************************
* GENERATE BILATERAL T CORRELATIONS
************************************************************************************************

use Ts_absolute_cfChina, clear
***** THETA
local theta = 828
foreach var of varlist T_benchmark T_China1 T_China2 {

	replace `var' = `var'^(100/`theta')
	
	egen logmean_`var' = mean(ln(`var')), by(ifscode)
	gen geommean_`var' = exp(logmean_`var')
	gen `var'_demean = `var'/geommean_`var'
	
	gen `var'_demean_China0 = `var'_demean if ifscode == 924
	egen `var'_demean_China = mean(`var'_demean_China0), by(isiccode dec)

}

save temp, replace

foreach var in T_benchmark T_China1 T_China2 {

use temp, clear
statsby "corr T_benchmark_demean `var'_demean_China" corr_`var' = r(rho) n_`var' = r(N), by(ifscode dec)

sort ifscode dec
save `var'_temp, replace

}

use T_benchmark_temp, clear
merge ifscode dec using T_China1_temp
tab _m
drop _m
sort ifscode dec
merge ifscode dec using T_China2_temp
tab _m
drop _m

label var corr_T_benchmark "Correlation of T's between country and China"
label var corr_T_China1 "Correlation of T's between country and UNBALANCED China counterfactual"
label var corr_T_China2 "Correlation of T's between country and BALANCED China counterfactual"

sort ifscode dec
save correlations_China, replace

erase temp.dta

************************************************************************************************
* GENERATE CORRELATIONS IN TRADE PATTERNS
************************************************************************************************

use sectoraltrade, clear

foreach var in ex im {
	gen total_`var'ports0 = s`var'ports if isiccode=="1"
	egen total_`var'ports = mean(total_`var'ports0), by(ifscode dec)

	gen share_`var' = s`var'ports/total_`var'ports
	drop total_`var'ports0 total_`var'ports
	
	gen share_`var'_china0 = share_`var' if ifscode == 924
	egen share_`var'_china = mean(share_`var'_china0), by(isiccode dec)
}

save temp, replace

************************************************************************************************
* 1) Correlation between China's export shares and country's export shares
************************************************************************************************

statsby "corr share_ex share_ex_china" corr_ex = r(rho) n_ex = r(N), by(ifscode dec)
label var corr_ex "Corr(Sectoral EX shares of ifscode,Sectoral EX shares of China)"
sort ifscode dec 
save corr_share_ex_China, replace

************************************************************************************************
* 2) Correlation between China's import shares and country's export shares
************************************************************************************************
use temp, clear
statsby "corr share_ex share_im_china" corr_ex_imChina = r(rho) n_ex_imChina = r(N), by(ifscode dec)
label var corr_ex_imChina "Corr(Sectoral EX shares of ifscode,Sectoral IM shares of China)"
sort ifscode dec 
save corr_share_ex_im_China, replace

************************************************************************************************
* 3) Correlation between China's import shares and country's export shares
************************************************************************************************
use temp, clear
statsby "corr share_im share_ex_china" corr_im_exChina = r(rho) n_im_exChina = r(N), by(ifscode dec)
label var corr_im_exChina "Corr(Sectoral IM shares of ifscode,Sectoral EX shares of China)"
sort ifscode dec 
merge ifscode dec using corr_share_ex_China
tab _m
drop _m
sort ifscode dec 
merge ifscode dec using corr_share_ex_im_China
tab _m
drop _m

sort ifscode dec
save exim_temp, replace

erase temp.dta 
erase corr_share_ex_China.dta
erase corr_share_ex_im_China.dta

************************************************************************************************
* MAIN MERGE
************************************************************************************************

use welfare, clear
sort ifscode

merge ifscode using our_regions_countries
tab _m
drop if _m~=3
drop _m

gen dec = 5

sort ifscode dec
merge ifscode dec using dni_withChina
tab _m
drop if _m==2
drop _m

sort ifscode dec
merge ifscode dec using correlations_China
tab _m
drop if _m==2
drop _m

sort ifscode dec
merge ifscode dec using pop_temp
tab _m
drop if _m==2
drop _m

sort ifscode dec
merge ifscode dec using exim_temp
tab _m
drop if _m==2
drop _m

************************************************************************************************
*** TABLE 1: Top and Bottom Countries in terms of d_ni and T correlation
************************************************************************************************

gsort -dni
gen rank = _n

outsheet country dni if rank<=10 | rank>=(75-10) using top_bottom_dni.csv, comma names replace

drop rank

sort corr_T_benchmark
gen rank = _n

outsheet country corr_T_benchmark if rank<=10 | rank>=(75-10) using top_bottom_correlation.csv, comma names replace

drop rank

************************************************************************************************
*** TABLE 3: Welfare Changes
************************************************************************************************

***** redefine region excluding China *****
replace region = "China" if ifscode == 924

gen dwelfare_bench_aut = 100*(benchmark/autarky - 1)

table region, c(mean dwelfare_bench_aut median dwelfare_bench_aut min dwelfare_bench_aut max dwelfare_bench_aut n dwelfare_bench_aut)

gen dwelfare_balanced_bench = 100*(counterfactual_balanced/benchmark - 1)

table region, c(mean dwelfare_balanced_bench median dwelfare_balanced_bench min dwelfare_balanced_bench max dwelfare_balanced_bench n dwelfare_balanced_bench)

gen dwelfare_unbalanced_bench = 100*(counterfactual_unbalanced/benchmark - 1)

table region, c(mean dwelfare_unbalanced_bench median dwelfare_unbalanced_bench min dwelfare_unbalanced_bench max dwelfare_unbalanced_bench n dwelfare_unbalanced_bench)

*******************************************************************
*** POPULATION-WEIGHTED -- Not in tables but mentioned in text.
*******************************************************************

sum dwelfare_bench_aut if ifscode~=924
sum dwelfare_bench_aut if ifscode~=924 [fw=int(pop)]

sum dwelfare_unbalanced_bench if ifscode~=924
sum dwelfare_unbalanced_bench if ifscode~=924 [fw=int(pop)]

sum dwelfare_balanced_bench if ifscode~=924
sum dwelfare_balanced_bench if ifscode~=924 [fw=int(pop)]

************************************************************************************************
*** FIGURE 2: GAINS FROM TRADE WITH CHINA: HEURISTIC CORRELATIONS
************************************************************************************************

gen ldni = log(dni)
gen lpop = log(pop)
reg dwelfare_bench_aut corr_im_exChina corr_ex corr_ex_imChina ldni lpop if ifscode~=924, r

*** Figure 3a
avplot corr_ex, mlabel(wbcode) mlabposition(0) msymbol(none) ytitle("Welfare Gains from China's Integration") xtitle("Corr(Country's Export shares, China's Export Shares)") graphregion(fcolor(white) lcolor(white)) note(,size(medium)) scale(1.3)
*** Figure 3b
avplot corr_ex_imChina, mlabel(wbcode) mlabposition(0) msymbol(none) ytitle("Welfare Gains from China's Integration") xtitle("Corr(Country's Export shares, China's Import Shares)") graphregion(fcolor(white) lcolor(white)) note(,size(medium)) scale(1.3)
*** Figure 3c
avplot corr_im_exChina, mlabel(wbcode) mlabposition(0) msymbol(none) ytitle("Welfare Gains from China's Integration") xtitle("Corr(Country's Import shares, China's Export Shares)") graphregion(fcolor(white) lcolor(white)) note(,size(medium)) scale(1.3)

************************************************************************************************
*** FIGURE 4: Welfare Gains in the Balanced and Unbalanced Counterfactuals
************************************************************************************************

*** Figure 4a
two (scatter dwelfare_balanced_bench dwelfare_unbalanced_bench, mlabel(wbcode) mlabposition(0) msymbol(none)) (line dwelfare_unbalanced_bench dwelfare_unbalanced_bench) if ifscode ~=924, legend(off) xtitle("Welfare Gain, Unbalanced Counterfactual") ytitle("Welfare Gain, Balanced Counterfactual") graphregion(fcolor(white) lcolor(white)) xsize(8) ysize(8)

*** Figure 4b
gen dwelfare_balanced_bench_exgw = 100*(balanced_exgw/benchmark - 1)
gen dwelfare_unbalanced_bench_exgw = 100*(unbalanced_exgw/benchmark - 1)

two (scatter dwelfare_balanced_bench_exgw dwelfare_unbalanced_bench_exgw, mlabel(wbcode) mlabposition(0) msymbol(none)) (line dwelfare_unbalanced_bench_exgw dwelfare_unbalanced_bench_exgw) if ifscode ~=924, legend(off) xtitle("Welfare Gain, Unbalanced Counterfactual") ytitle("Welfare Gain, Balanced Counterfactual") graphregion(fcolor(white) lcolor(white)) xsize(8) ysize(8)

************************************************************************************************
*** FIGURE 6: Welfare Gains Under Fixed and Endogenous Factor Prices
************************************************************************************************

*** Figure 6a
two (scatter dwelfare_balanced_bench dwelfare_balanced_bench_exgw, mlabel(wbcode) mlabposition(0) msymbol(none)) (lfit dwelfare_balanced_bench_exgw dwelfare_balanced_bench_exgw) (lfit dwelfare_balanced_bench dwelfare_balanced_bench_exgw) if ifscode~=924, xlabels(0 0.5 1 1.5 2) ylabels(0 0.5 1 1.5 2) xsize(8) ysize(8) legend(off) xtitle("Welfare Gain, Fixed w and r") ytitle("Welfare Gain, Endogenous w and r") graphregion(fcolor(white) lcolor(white))

*** Figure 6b
two (scatter dwelfare_unbalanced_bench dwelfare_unbalanced_bench_exgw, mlabel(wbcode) mlabposition(0) msymbol(none)) (lfit dwelfare_unbalanced_bench_exgw dwelfare_unbalanced_bench_exgw) (lfit dwelfare_unbalanced_bench dwelfare_unbalanced_bench_exgw) if ifscode~=924, xlabels(0 1 2 3 4 5) ylabels(0 1 2 3 4 5) xsize(8) ysize(8) legend(off) xtitle("Welfare Gain, Fixed w and r") ytitle("Welfare Gain, Endogenous w and r") graphregion(fcolor(white) lcolor(white))

************************************************************************************************
*** FIGURE 7: Unbalanced Counterfactual Welfare Gains and Technological Similarity
************************************************************************************************

gen chg_corr = corr_T_China1 - corr_T_benchmark

*** Figure 7a
two (scatter dwelfare_unbalanced_bench chg_corr, mlabel(wbcode) mlabposition(0) msymbol(none)) (lfit dwelfare_unbalanced_bench chg_corr) if ifscode~=924, legend(off) xtitle("Change in the Correlation of T's with China") ytitle("Welfare Gain, Unbalanced Counterfactual") graphregion(fcolor(white) lcolor(white))

*** Figure 7b
two (scatter dwelfare_unbalanced_bench_exgw chg_corr, mlabel(wbcode) mlabposition(0) msymbol(none)) (lfit dwelfare_unbalanced_bench_exgw chg_corr) if ifscode~=924, legend(off) xtitle("Change in the Correlation of T's with China") ytitle("Welfare Gain, Unbalanced Counterfactual") graphregion(fcolor(white) lcolor(white))

************************************************************************************************
*** APPENDIX TABLE A1: Country Coverage and Welfare Changes in the Main Counterfactuals
************************************************************************************************
sort region country
outsheet region country dwelfare_balanced_bench dwelfare_unbalanced_bench using dwelfare_by_country.csv, comma replace

************************************************************************************************
************************************************************************************************
*** SECTORAL PRODUCTIVITIES: FIGURES 3 AND 5
************************************************************************************************
************************************************************************************************

use Ts_10year828, clear

egen T_rank = rank(T_2us), by(isiccode dec) field
egen T_first = max(T_2us), by(isiccode dec)
gen T_second0 = T_2us if T_rank == 2
egen T_second = mean(T_second0), by(isiccode dec)
gen T_frontier = sqrt(T_first*T_second)

gen T_2fr = T_2us/T_frontier
gen T_2fr_theta = T_2fr^(1/8.28)

egen rankCA = rank(T_2fr) if isiccode~="1", by(ifscode dec) field
label var dec "Decade"

/*********************************************************************
****** DEFINE THE MAIN T VARIABLE
*********************************************************************/
gen T = T_2fr_theta

gen lT = ln(T)

**** 1) geometric average in each decade:

egen mean_lT = mean(lT), by(ifscode dec)

gen geommean_T = exp(mean_lT)

**** 2) growth between 1990s and 2000s

egen cs = group(ifscode s)
tsset cs dec

gen gr_geommean_T = geommean_T/l.geommean_T

**** 3) NEW LEVEL: constant fraction of the world frontier:

gen newT_tilted = gr_geommean_T*geommean_T

**** 3) NEW LEVEL: balanced growth

gen newT_balanced = gr_geommean_T*T

label var newT_tilted "Unbalanced Counterfactual T"
label var newT_balanced "Balanced Counterfactual T"
label var geommean_T "Average Actual T"
label var T "Actual T"

************************************************************************************************
*** FIGURE 3: China: Actual and Counterfactual Productivities 
************************************************************************************************

two (scatter T rankCA, mlabel(isiccode) mlabposition(12)) (line geommean_T rankCA, lcolor(black)) (scatter newT_tilted rankCA, msymbol(triangle_hollow)) (scatter newT_balanced rankCA, msymbol(circle_hollow) mcolor(red)) if ifscode == 924 & dec == 5, xtitle("") ytitle("Ratio to World Frontier") graphregion(fcolor(white) lcolor(white))

************************************************************************************************
*** FIGURE 5: Chinas and World Average Comparative Advantage 
************************************************************************************************

egen averageT0 = mean(T) if ifscode~=924, by(isiccode dec)
egen averageT = mean(averageT0), by(isiccode dec)
label var averageT "Global Average Distance to Frontier"

two (scatter T averageT, mlabel(isiccode))(lfit T averageT) if dec == 5 & ifscode == 924 & isiccode~="16", ytitle("China's Distance to Frontier") xtitle("Global Average Distance to Frontier") legend(off) graphregion(fcolor(white) lcolor(white))

duplicates drop s alpha, force

************************************************************************************************
*** Appendix Table A2: Sectors
************************************************************************************************
outsheet isiccode isicname alpha beta gamma_NT omega using sectors.csv, comma replace 

************************************************************************************************
************************************************************************************************
*** MATCH OF THE MODEL TO THE DATA: TABLE 2 and FIGURE 1
************************************************************************************************
************************************************************************************************

************************************************************************************************
*** TABLE 2: The Fit of the Baseline Model with the Data: w and r
************************************************************************************************

use Ts_10year828, clear
keep if dec == 5
duplicates drop ifscode w_2us r_2us, force

keep ifscode dec w_2us r_2us
sort ifscode dec

merge ifscode dec using w_r_model
tab _m
drop _m

order ifscode country dec w_2us r_2us w_model r_model

gen r_model_us0 = r_model if ifscode == 111
egen r_model_us = mean(r_model_us0), by(dec)
gen r_model_2us = r_model/r_model_us

gen one = 1

table one if dec == 5, c(mean w_model mean w_2us count w_model count w_2us)
table one if dec == 5, c(median w_model median w_2us)
pwcorr w_model w_2us if dec == 5, obs

table one if dec == 5, c(mean r_model_2us mean r_2us count r_model_2us count r_model_2us)
table one if dec == 5, c(median r_model_2us median r_2us)
pwcorr r_model_2us r_2us if dec == 5, obs

************************************************************************************************
*** TABLE 2: The Fit of the Baseline Model with the Data: pi_nn and p_ni
************************************************************************************************

use pi_model_actual, clear

gen one = 1

**** OVERALL AVERAGES
table one if pi_ni_diag~=. & pi_ni_model_diag ~=., c(mean pi_ni_model_diag mean pi_ni_diag count pi_ni_model_diag count pi_ni_diag)
table one if pi_ni_diag~=. & pi_ni_model_diag ~=., c(median pi_ni_model_diag median pi_ni_diag)
pwcorr pi_ni_diag pi_ni_model_diag

table one if pi_ni_offdiag~=. & pi_ni_model_offdiag ~=., c(mean pi_ni_model_offdiag mean pi_ni_offdiag count pi_ni_model_offdiag count pi_ni_offdiag)
table one if pi_ni_offdiag~=. & pi_ni_model_offdiag ~=., c(median pi_ni_model_offdiag median pi_ni_offdiag)
pwcorr pi_ni_offdiag pi_ni_model_offdiag

************************************************************************************************
*** FIGURE 1: Benchmark Model vs. Data: j for China and the Rest of the Sample
************************************************************************************************

two (scatter pi_ni_model pi_ni if ifscode1 ~= 924 & ifscode2 ~= 924, msymbol(circle_hollow) ) (scatter pi_ni_model_china pi_ni_china, mcolor(red)) (lfit pi_ni pi_ni, lcolor(black)), ytitle("Model {&pi}{sub:ni}") xtitle("Data {&pi}{sub:ni}") legend(label(1 "Non-China Pairs") label(2 "China Pairs") order(2 1)) graphregion(fcolor(white) lcolor(white)) xsize(8) ysize(8)
